@@ -79,7 +79,7 @@ typedef struct
    unsigned int NameLen;
    unsigned int DataLen;
    unsigned int Argument;          // Named "flags" in original aff source, named "arg" in afinfo output.
-   char         Name[];            //lint !e1501
+   char         Name[0];
 } __attribute__ ((packed)) t_AffSegmentHeader;
 
 // Between header and footer lie the segment name and the data
