@@ -9,22 +9,22 @@
 //  Module:         Standard include file
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 
 #ifdef LINT_CODE_CHECK
@@ -61,6 +61,8 @@
 
 #include <limits.h>
 
+#include <qglobal.h>
+
 #include "toolglobalid.h"
 #include "toolerror.h"
 #include "toollog.h"
@@ -69,7 +71,7 @@
 #include "modules.h"
 #include "error.h"
 
-#define QSTR_TO_PSZ(QStr) (QStr).toAscii().constData()
+#define QSTR_TO_PSZ(QStr) (QStr).toLatin1().constData()
 
 
 extern void *pOffsetOfNullPointer;
