@@ -718,12 +718,12 @@ QVariant t_Device::GetAverageSpeed (t_pDevice pDevice)
 
 QVariant t_Device::GetRemaining (t_pDevice pDevice)
 {
-   QString Result;
-   char    Buff[10];
-   int     TotalSeconds;
-   time_t  Now;
-   int     hh, mm, ss;
-   quint64 Current, Total;
+   QString      Result;
+   char         Buff[20];
+   int          TotalSeconds;
+   time_t       Now;
+   unsigned int hh, mm, ss;
+   quint64      Current, Total;
 
    if (!pDevice->Error.Abort() && ((pDevice->State == Acquire) || // Don't display anything if no acquisition is running
                                    (pDevice->State == Verify )))
@@ -737,7 +737,7 @@ QVariant t_Device::GetRemaining (t_pDevice pDevice)
       else
       {
          DeviceGetProgress (pDevice, &Current, &Total);
-         ss  = (int) ((double)Total / Current * TotalSeconds); // Estimated total time
+         ss  = (unsigned int) ((double)Total / Current * TotalSeconds); // Estimated total time
          ss -= TotalSeconds;                                   // Estimated remaining time
          hh = ss / SECONDS_PER_HOUR;   ss %= SECONDS_PER_HOUR;
          mm = ss / SECONDS_PER_MINUTE; ss %= SECONDS_PER_MINUTE;
