@@ -1,16 +1,16 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="en" sourcelanguage="en">
+<TS version="2.1" language="en" sourcelanguage="en">
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="+466"/>
+        <location filename="main.cpp" line="+509"/>
         <source>Guymager needs to be started with root rights in order to perform acquisitions. You are not root and thus won&apos;t be able to acquire devices.
 Continue anyway?</source>
         <translation type="unfinished">GUYMAGER需要以管理员的身份运行，你目前不是管理员权限，确定继续吗？</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1468"/>
+        <location filename="threadwrite.cpp" line="+1480"/>
         <source>Deleting %1</source>
         <translation type="unfinished">删除 %1</translation>
     </message>
@@ -21,9 +21,9 @@ Continue anyway?</source>
         <translation type="unfinished">非管理员权限</translation>
     </message>
     <message>
-        <location filename="dlgabort.cpp" line="+82"/>
-        <location filename="dlgacquire.cpp" line="+795"/>
-        <location filename="dlgdirsel.cpp" line="+100"/>
+        <location filename="dlgabort.cpp" line="+83"/>
+        <location filename="dlgacquire.cpp" line="+811"/>
+        <location filename="dlgdirsel.cpp" line="+106"/>
         <source>Ok</source>
         <translation type="unfinished">确定</translation>
     </message>
@@ -41,7 +41,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+23"/>
+        <location line="+24"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -51,7 +51,7 @@ Continue anyway?</source>
         <translation type="unfinished">A高级司法镜像</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1010"/>
+        <location filename="threadscan.cpp" line="+1440"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation type="unfinished">GUYMAGER 无法扫描到设备</translation>
     </message>
@@ -71,7 +71,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-28"/>
+        <location filename="file.cpp" line="-29"/>
         <source>Creation of a clone</source>
         <translation type="unfinished">创建一个克隆</translation>
     </message>
@@ -148,7 +148,7 @@ remaining</source>
         <translation type="obsolete">剩余时间</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+44"/>
+        <location filename="mainwindow.h" line="+49"/>
         <source>Model</source>
         <translation type="unfinished">设备名</translation>
     </message>
@@ -167,7 +167,7 @@ remaining</source>
         <translation type="obsolete">备注</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-383"/>
+        <location filename="dlgacquire.cpp" line="-392"/>
         <source>Remark</source>
         <translation type="unfinished"></translation>
     </message>
@@ -279,12 +279,12 @@ remaining</source>
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="dlgacquire.cpp" line="+210"/>
+        <location filename="dlgacquire.cpp" line="+212"/>
         <source>File format</source>
         <translation type="unfinished">格式化文件</translation>
     </message>
     <message>
-        <location line="+84"/>
+        <location line="+91"/>
         <source>Destination</source>
         <translation type="unfinished">目标</translation>
     </message>
@@ -294,19 +294,18 @@ remaining</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+549"/>
         <source>The filenames contain special characters which are not allowed. Guymager suggests the following changes:
 	Image filename: %1
 	Info filename: %2
 Do you accept these changes?</source>
-        <translation type="unfinished">文件名不允许包含特殊字符
+        <translation type="obsolete">文件名不允许包含特殊字符
 图像文件名：%1
 信息文件名：%2
 是否同意此项变化</translation>
     </message>
     <message>
-        <location filename="config.h" line="+266"/>
-        <location filename="table.cpp" line="+309"/>
+        <location filename="config.h" line="+274"/>
+        <location filename="table.cpp" line="+345"/>
         <source>EwfCaseNumber</source>
         <translation type="unfinished">案件序列号</translation>
     </message>
@@ -345,19 +344,19 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-256"/>
+        <location filename="dlgacquire.cpp" line="+297"/>
         <source>Select destination directory</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">选择目标目录</translation>
     </message>
     <message>
-        <location line="-369"/>
+        <location line="-380"/>
         <location line="+1"/>
         <source>(file extension %1)</source>
         <translation type="unfinished">文件扩展名%1</translation>
     </message>
     <message>
-        <location line="+629"/>
+        <location line="+688"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">特殊字符</translation>
@@ -373,13 +372,13 @@ Do you accept these changes?</source>
         <translation type="unfinished">信息目录</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1017"/>
+        <location filename="dlgacquire.cpp" line="-1075"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+903"/>
+        <location line="+958"/>
         <source>Access denied</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">访问被拒绝</translation>
@@ -405,19 +404,19 @@ Do you accept these changes?</source>
         <translation type="unfinished">验证目标盘哈希值</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-425"/>
+        <location filename="dlgacquire.cpp" line="-474"/>
         <source>Hash calculation / verification</source>
         <translation type="unfinished">哈希值计算/校验</translation>
     </message>
     <message>
-        <location line="+426"/>
+        <location line="+475"/>
         <source>Guymager cannot write to the directory
 	%1
 This may be due to insufficient access rights or unsupported filename characters. Please choose another directory.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-740"/>
+        <location line="-798"/>
         <source>Local device, cannot be written</source>
         <translation type="unfinished">本地设备，不能写入</translation>
     </message>
@@ -437,21 +436,20 @@ This may be due to insufficient access rights or unsupported filename characters
         <translation type="unfinished">可以进行拷贝</translation>
     </message>
     <message>
-        <location line="+806"/>
+        <location line="+862"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+31"/>
         <source>The info filename contains special characters which are not allowed. Guymager suggests the following changes:
 	%1
 Do you accept these changes?</source>
-        <translation type="unfinished">文件名中不允许包含特殊字符。
+        <translation type="obsolete">文件名中不允许包含特殊字符。
 	%1
 确定接受吗？</translation>
     </message>
     <message>
-        <location line="+95"/>
+        <location line="+174"/>
         <source>Files exist</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">文件已存在</translation>
@@ -462,7 +460,7 @@ Do you accept these changes?</source>
         <translation type="unfinished">图像或信息文件已存在，确定覆盖吗？</translation>
     </message>
     <message>
-        <location line="-777"/>
+        <location line="-881"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation type="unfinished">拷贝%1</translation>
@@ -494,12 +492,12 @@ Do you accept these changes?</source>
         <translation type="unfinished">分卷镜像文件</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="+215"/>
+        <location filename="dlgacquire.cpp" line="+217"/>
         <source>(file extension %1 or %2)</source>
         <translation type="unfinished">（文件扩展名%1或%2）</translation>
     </message>
     <message>
-        <location line="+564"/>
+        <location line="+618"/>
         <location line="+15"/>
         <location line="+12"/>
         <source>Incorrect value</source>
@@ -512,7 +510,18 @@ Do you accept these changes?</source>
         <translation type="unfinished">分卷大小“%1”是无效的。只能输入一个正数。</translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+163"/>
+        <source>Files already used</source>
+        <comment>Dialog title</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The image or info files already are used in the acquisition of %1. Please chose different ones.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+38"/>
         <source>The info file already exists. Do you want to overwrite it?</source>
         <translation type="unfinished">信息文件已存在。确定覆盖吗？</translation>
     </message>
@@ -522,7 +531,7 @@ Do you accept these changes?</source>
         <translation type="unfinished">拆分文件单位</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-139"/>
+        <location filename="dlgacquire.cpp" line="-187"/>
         <source>The split size for the selected image format must be in the range %1MiB - %2EiB.</source>
         <translation type="unfinished">为选定的镜像格式拆分大小，必须在%1Mib - %2EiB 范围内。</translation>
     </message>
@@ -531,7 +540,7 @@ Do you accept these changes?</source>
         <translation type="obsolete">EWF格式的拆分大小必须在%1 - %2 MiB范围内。如果需要支持更大的文件，使用Encase6 格式或更高版本（参考配置文件，参数EwfFormat）</translation>
     </message>
     <message>
-        <location line="+165"/>
+        <location line="+213"/>
         <source>Large amount of segment files</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -554,7 +563,7 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-992"/>
+        <location filename="dlgacquire.cpp" line="-1096"/>
         <source>Selected for first acquisition</source>
         <translation type="unfinished"></translation>
     </message>
@@ -571,7 +580,55 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+716"/>
+        <location line="+570"/>
+        <source>Path not found</source>
+        <comment>Dialog title</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The destination directory
+   %1
+doesn&apos;t exist. Do you want to create it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+169"/>
+        <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image directory:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image filename:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info directory:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info filename:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>
+Do you accept these changes?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+33"/>
         <source>Destination in use</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -593,7 +650,7 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-541"/>
+        <location line="-595"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation type="unfinished"></translation>
@@ -605,12 +662,12 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-177"/>
+        <location line="-184"/>
         <source>Duplicate image settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+804"/>
+        <location line="+906"/>
         <source>There possibly is not enough space left on the destination path.
 Source data size: %1
 Free space on destination: %2
@@ -622,7 +679,7 @@ Do you want to continue anyway?</source>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+79"/>
+        <location filename="dlgautoexit.cpp" line="+85"/>
         <source>Abort</source>
         <translation type="unfinished">终止</translation>
     </message>
@@ -667,7 +724,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+94"/>
+        <location filename="dlgmessage.cpp" line="+100"/>
         <source>Close</source>
         <translation type="unfinished">关闭</translation>
     </message>
@@ -675,7 +732,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+200"/>
+        <location filename="info.cpp" line="+201"/>
         <source>Command executed: %1</source>
         <translation type="unfinished">执行命令：%1</translation>
     </message>
@@ -693,7 +750,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+105"/>
+        <location filename="infofield.cpp" line="+109"/>
         <source>Size</source>
         <translation type="unfinished">大小</translation>
     </message>
@@ -809,7 +866,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+391"/>
+        <location filename="device.cpp" line="+398"/>
         <source>Local device</source>
         <translation type="unfinished">本地设备</translation>
     </message>
@@ -833,7 +890,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="obsolete">中止-错误：原因“none”</translation>
     </message>
     <message>
-        <location line="-353"/>
+        <location line="-355"/>
         <source>Aborted by user</source>
         <translation type="unfinished">用户中断</translation>
     </message>
@@ -846,7 +903,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="obsolete">中止 - 硬盘读取错误</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+281"/>
+        <location filename="mainwindow.cpp" line="+291"/>
         <source>&amp;Rescan</source>
         <translation type="unfinished">&amp;R重新扫描</translation>
     </message>
@@ -856,7 +913,13 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+346"/>
+        <location line="+195"/>
+        <source>Device already contained</source>
+        <comment>Dialog title</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+154"/>
         <source>There are active acquisitions. Do you really want to abort them and quit?</source>
         <translation type="unfinished">There are active acquisitions. 你确定放弃并退出？</translation>
     </message>
@@ -896,7 +959,7 @@ Using libguytools %5</source>
         <translation type="unfinished">退出</translation>
     </message>
     <message>
-        <location line="-341"/>
+        <location line="-344"/>
         <source>&amp;Devices</source>
         <translation type="unfinished">&amp;D设备</translation>
     </message>
@@ -939,7 +1002,7 @@ Using libguytools %5</source>
         <translation type="obsolete">正在验证中</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+350"/>
+        <location filename="device.cpp" line="+352"/>
         <source>Device disconnected, acquisition paused</source>
         <translation type="unfinished">设备断开，暂停获取</translation>
     </message>
@@ -990,7 +1053,7 @@ Using libguytools %5</source>
         <translation type="unfinished">添加特殊设备</translation>
     </message>
     <message>
-        <location line="+152"/>
+        <location line="+155"/>
         <source>Open File</source>
         <translation type="unfinished">打开文件</translation>
     </message>
@@ -1007,13 +1070,12 @@ Using libguytools %5</source>
         <translation type="unfinished">手动添加特殊设备</translation>
     </message>
     <message>
-        <location line="+6"/>
         <source>Device alrady contained</source>
         <comment>Dialog title</comment>
-        <translation type="unfinished">载入设备准备完成</translation>
+        <translation type="obsolete">载入设备准备完成</translation>
     </message>
     <message>
-        <location line="+0"/>
+        <location line="+6"/>
         <source>The selected file or device already is contained in the table.</source>
         <translation type="unfinished">选定的文件或设备已经加载到列表中</translation>
     </message>
@@ -1050,12 +1112,12 @@ Using libguytools %5</source>
         <translation type="unfinished">未知</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-170"/>
+        <location filename="mainwindow.cpp" line="-173"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished">在获取完成后退出</translation>
     </message>
     <message>
-        <location line="+402"/>
+        <location line="+405"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1071,7 +1133,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-466"/>
+        <location filename="device.cpp" line="-468"/>
         <source>Acquisition start failure</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1126,7 +1188,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+276"/>
+        <location line="+278"/>
         <source>Running</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1194,7 +1256,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-393"/>
+        <location line="-395"/>
         <source>Too many bad sectors</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1204,7 +1266,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+294"/>
+        <location line="+296"/>
         <source>Queued</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1212,7 +1274,7 @@ Linked with libguytools %6</source>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-164"/>
+        <location filename="table.cpp" line="-190"/>
         <source>Local Device - cannot be acquired</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1223,31 +1285,31 @@ Linked with libguytools %6</source>
         <translation type="unfinished">信息</translation>
     </message>
     <message>
-        <location line="+138"/>
+        <location line="+149"/>
         <source>Device info</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">设备信息</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+26"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation type="unfinished">GUYMAGER取信息文件</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+13"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation type="unfinished">GUYMAGER</translation>
     </message>
     <message>
-        <location line="+11"/>
+        <location line="+14"/>
         <source>Device information</source>
         <comment>Info file</comment>
         <translation type="unfinished">设备信息</translation>
     </message>
     <message>
-        <location line="+528"/>
+        <location line="+579"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation type="unfinished">成功完成</translation>
@@ -1259,13 +1321,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="-45"/>
         <source>Aborted by user</source>
         <comment>Info file</comment>
         <translation type="unfinished">用户中止</translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+34"/>
         <source>Aborted because of image write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1276,19 +1338,19 @@ Linked with libguytools %6</source>
         <translation type="obsolete">中止 - 原因（%1）</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+30"/>
         <source>Strange state (%1)</source>
         <comment>Info file</comment>
         <translation type="unfinished">状态（%1）</translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+3"/>
         <source>State: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-163"/>
+        <location line="-174"/>
         <source>During verification, %1 bad sectors have been encountered. The sector numbers are:</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1312,13 +1374,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+76"/>
+        <location line="+58"/>
         <source>(during acquisition)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+77"/>
+        <location line="+106"/>
         <source>(ISO format YYYY-MM-DD HH:MM:SS)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1328,7 +1390,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-629"/>
+        <location line="-642"/>
         <source>Linux device:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1340,7 +1402,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+630"/>
+        <location line="+643"/>
         <location line="+24"/>
         <source>Acquisition started:: %1</source>
         <comment>Info file</comment>
@@ -1367,19 +1429,19 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-155"/>
+        <location line="-164"/>
         <source>--</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+74"/>
+        <location line="+83"/>
         <source>MD5 hash:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-603"/>
+        <location line="-619"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1409,13 +1471,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+667"/>
+        <location line="+683"/>
         <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-626"/>
+        <location line="-639"/>
         <source>Source verification:: on</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1427,25 +1489,43 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+523"/>
+        <location line="+507"/>
         <source>(during source verification)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+40"/>
+        <location line="+69"/>
         <source>SHA256 hash:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-571"/>
+        <location line="-584"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="-36"/>
+        <source>Host name:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+1"/>
+        <source>Domain name:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>System:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+35"/>
         <source>Info  path and file name:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1463,13 +1543,26 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+535"/>
+        <location line="+516"/>
+        <source>Aborted, too many bad sectors (&gt; %1)</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Aborted because device has been inaccessible for too long (&gt; %1s)</source>
+        <oldsource>Aborted because device has is inaccessible for too long (&gt; %1s)</oldsource>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+6"/>
         <source>Aborted because of image read error during verification</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+42"/>
         <source>MD5 hash verified source:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1518,13 +1611,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-800"/>
+        <location line="-839"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+196"/>
+        <location line="+222"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1536,7 +1629,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-196"/>
+        <location line="-222"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
@@ -1554,7 +1647,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+186"/>
+        <location line="+212"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1566,12 +1659,12 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-152"/>
+        <location line="-178"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+822"/>
+        <location line="+861"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1587,47 +1680,47 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-837"/>
+        <location line="-876"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+718"/>
+        <location line="+734"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-12"/>
+        <location line="-21"/>
         <source>Aborted because acquisition failed to start</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+122"/>
+        <location line="+154"/>
         <source>No MD5 hashes available (the selected EWF format does not support image file hashes)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-659"/>
+        <location line="-672"/>
         <source>Hash calculation:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+534"/>
+        <location line="+521"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+19"/>
         <source>Aborted, strange reason (%1 %2)</source>
         <comment>Info file</comment>
         <translation type="unfinished">中止 - 原因（%1） {1 %2)?}</translation>
     </message>
     <message>
-        <location line="+14"/>
+        <location line="+37"/>
         <source>SHA1 hash:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1645,13 +1738,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-594"/>
+        <location line="-607"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+712"/>
+        <location line="+725"/>
         <source>Acquisition/verification aborted - file list may be incomplete</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1659,7 +1752,7 @@ Linked with libguytools %6</source>
 <context>
     <name>t_ThreadScan</name>
     <message>
-        <location filename="threadscan.cpp" line="+52"/>
+        <location filename="threadscan.cpp" line="+53"/>
         <source>Cannot scan devices</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">无法扫描设备</translation>
