@@ -1,12 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="it">
+<TS version="2.1" language="it">
 <context>
     <name>QObject</name>
     <message>
-        <location filename="dlgabort.cpp" line="+82"/>
-        <location filename="dlgacquire.cpp" line="+795"/>
-        <location filename="dlgdirsel.cpp" line="+100"/>
+        <location filename="dlgabort.cpp" line="+83"/>
+        <location filename="dlgacquire.cpp" line="+811"/>
+        <location filename="dlgdirsel.cpp" line="+106"/>
         <source>Ok</source>
         <translation type="unfinished"></translation>
     </message>
@@ -24,12 +24,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+23"/>
+        <location line="+24"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+465"/>
+        <location filename="main.cpp" line="+508"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -41,7 +41,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1468"/>
+        <location filename="threadwrite.cpp" line="+1480"/>
         <source>Deleting %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -51,7 +51,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1010"/>
+        <location filename="threadscan.cpp" line="+1440"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -71,7 +71,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-28"/>
+        <location filename="file.cpp" line="-29"/>
         <source>Creation of a clone</source>
         <translation type="unfinished"></translation>
     </message>
@@ -89,12 +89,12 @@ Continue anyway?</source>
 <context>
     <name>t_DeviceListModel</name>
     <message>
-        <location line="-383"/>
+        <location line="-392"/>
         <source>Remark</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+42"/>
+        <location filename="mainwindow.h" line="+47"/>
         <source>SerialNr</source>
         <translation type="unfinished"></translation>
     </message>
@@ -216,8 +216,8 @@ Continue anyway?</source>
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+266"/>
-        <location filename="table.cpp" line="+309"/>
+        <location filename="config.h" line="+274"/>
+        <location filename="table.cpp" line="+345"/>
         <source>EwfCaseNumber</source>
         <translation type="unfinished"></translation>
     </message>
@@ -256,7 +256,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="+210"/>
+        <location filename="dlgacquire.cpp" line="+212"/>
         <source>File format</source>
         <translation type="unfinished"></translation>
     </message>
@@ -267,7 +267,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+61"/>
+        <location line="+68"/>
         <source>Destination</source>
         <translation type="unfinished"></translation>
     </message>
@@ -277,25 +277,17 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+293"/>
+        <location line="+297"/>
         <source>Select destination directory</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+261"/>
+        <location line="+309"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location line="-5"/>
-        <source>The filenames contain special characters which are not allowed. Guymager suggests the following changes:
-	Image filename: %1
-	Info filename: %2
-Do you accept these changes?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="config.h" line="-3"/>
         <source>DestImageDirectory</source>
@@ -307,13 +299,13 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1012"/>
+        <location filename="dlgacquire.cpp" line="-1075"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+903"/>
+        <location line="+958"/>
         <source>Access denied</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -339,19 +331,19 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-425"/>
+        <location filename="dlgacquire.cpp" line="-474"/>
         <source>Hash calculation / verification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+426"/>
+        <location line="+475"/>
         <source>Guymager cannot write to the directory
 	%1
 This may be due to insufficient access rights or unsupported filename characters. Please choose another directory.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-740"/>
+        <location line="-798"/>
         <source>Local device, cannot be written</source>
         <translation type="unfinished"></translation>
     </message>
@@ -371,19 +363,23 @@ This may be due to insufficient access rights or unsupported filename characters
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+806"/>
+        <location line="+862"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+31"/>
-        <source>The info filename contains special characters which are not allowed. Guymager suggests the following changes:
-	%1
-Do you accept these changes?</source>
+        <location line="+136"/>
+        <source>Files already used</source>
+        <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+95"/>
+        <location line="+1"/>
+        <source>The image or info files already are used in the acquisition of %1. Please chose different ones.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+37"/>
         <source>Files exist</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -394,7 +390,7 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-777"/>
+        <location line="-881"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation type="unfinished"></translation>
@@ -426,12 +422,12 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="+215"/>
+        <location filename="dlgacquire.cpp" line="+217"/>
         <source>(file extension %1 or %2)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+564"/>
+        <location line="+618"/>
         <location line="+15"/>
         <location line="+12"/>
         <source>Incorrect value</source>
@@ -444,7 +440,7 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+154"/>
+        <location line="+202"/>
         <source>The info file already exists. Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -454,12 +450,12 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-139"/>
+        <location filename="dlgacquire.cpp" line="-187"/>
         <source>The split size for the selected image format must be in the range %1MiB - %2EiB.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+165"/>
+        <location line="+213"/>
         <source>Large amount of segment files</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -482,7 +478,7 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-992"/>
+        <location filename="dlgacquire.cpp" line="-1096"/>
         <source>Selected for first acquisition</source>
         <translation type="unfinished"></translation>
     </message>
@@ -499,7 +495,55 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+716"/>
+        <location line="+570"/>
+        <source>Path not found</source>
+        <comment>Dialog title</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>The destination directory
+   %1
+doesn&apos;t exist. Do you want to create it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+169"/>
+        <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image directory:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Image filename:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info directory:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>
+   Info filename:	%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>
+Do you accept these changes?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+33"/>
         <source>Destination in use</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -521,7 +565,7 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-541"/>
+        <location line="-595"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation type="unfinished"></translation>
@@ -533,12 +577,12 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-177"/>
+        <location line="-184"/>
         <source>Duplicate image settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+804"/>
+        <location line="+906"/>
         <source>There possibly is not enough space left on the destination path.
 Source data size: %1
 Free space on destination: %2
@@ -550,7 +594,7 @@ Do you want to continue anyway?</source>
 <context>
     <name>t_DlgAutoExit</name>
     <message>
-        <location filename="dlgautoexit.cpp" line="+79"/>
+        <location filename="dlgautoexit.cpp" line="+85"/>
         <source>Abort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -594,7 +638,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_DlgMessage</name>
     <message>
-        <location filename="dlgmessage.cpp" line="+94"/>
+        <location filename="dlgmessage.cpp" line="+100"/>
         <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
@@ -602,7 +646,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+200"/>
+        <location filename="info.cpp" line="+201"/>
         <source>Command executed: %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -620,7 +664,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+105"/>
+        <location filename="infofield.cpp" line="+109"/>
         <source>Size</source>
         <translation type="unfinished"></translation>
     </message>
@@ -723,7 +767,7 @@ Guymager will exit automatically in %1 seconds.</source>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+391"/>
+        <location filename="device.cpp" line="+398"/>
         <source>Local device</source>
         <translation type="unfinished"></translation>
     </message>
@@ -743,12 +787,12 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-353"/>
+        <location line="-355"/>
         <source>Aborted by user</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+281"/>
+        <location filename="mainwindow.cpp" line="+291"/>
         <source>&amp;Rescan</source>
         <translation type="unfinished"></translation>
     </message>
@@ -793,7 +837,13 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+326"/>
+        <location line="+175"/>
+        <source>Device already contained</source>
+        <comment>Dialog title</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+154"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -821,7 +871,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+350"/>
+        <location filename="device.cpp" line="+352"/>
         <source>Device disconnected, acquisition paused</source>
         <translation type="unfinished"></translation>
     </message>
@@ -849,7 +899,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-431"/>
+        <location filename="mainwindow.cpp" line="-434"/>
         <source>Rescan devices and update table</source>
         <translation type="unfinished"></translation>
     </message>
@@ -860,7 +910,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+152"/>
+        <location line="+155"/>
         <source>Open File</source>
         <translation type="unfinished"></translation>
     </message>
@@ -878,12 +928,6 @@ Guymager will exit automatically in %1 seconds.</source>
     </message>
     <message>
         <location line="+6"/>
-        <source>Device alrady contained</source>
-        <comment>Dialog title</comment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location line="+0"/>
         <source>The selected file or device already is contained in the table.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -920,12 +964,12 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-170"/>
+        <location filename="mainwindow.cpp" line="-173"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+402"/>
+        <location line="+405"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -941,7 +985,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-466"/>
+        <location filename="device.cpp" line="-468"/>
         <source>Acquisition start failure</source>
         <translation type="unfinished"></translation>
     </message>
@@ -996,7 +1040,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+276"/>
+        <location line="+278"/>
         <source>Running</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1064,7 +1108,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-393"/>
+        <location line="-395"/>
         <source>Too many bad sectors</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1074,7 +1118,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+294"/>
+        <location line="+296"/>
         <source>Queued</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1082,7 +1126,7 @@ Linked with libguytools %6</source>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-202"/>
+        <location filename="table.cpp" line="-228"/>
         <source>Info</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
@@ -1093,31 +1137,31 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+100"/>
+        <location line="+111"/>
         <source>Device info</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+26"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+13"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+11"/>
+        <location line="+14"/>
         <source>Device information</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+528"/>
+        <location line="+579"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1129,31 +1173,31 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+22"/>
+        <location line="-45"/>
         <source>Aborted by user</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+34"/>
         <source>Aborted because of image write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+30"/>
         <source>Strange state (%1)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+2"/>
+        <location line="+3"/>
         <source>State: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-163"/>
+        <location line="-174"/>
         <source>During verification, %1 bad sectors have been encountered. The sector numbers are:</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1177,13 +1221,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+76"/>
+        <location line="+58"/>
         <source>(during acquisition)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+77"/>
+        <location line="+106"/>
         <source>(ISO format YYYY-MM-DD HH:MM:SS)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1193,7 +1237,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-629"/>
+        <location line="-642"/>
         <source>Linux device:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1205,7 +1249,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+630"/>
+        <location line="+643"/>
         <location line="+24"/>
         <source>Acquisition started:: %1</source>
         <comment>Info file</comment>
@@ -1232,19 +1276,19 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-155"/>
+        <location line="-164"/>
         <source>--</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+74"/>
+        <location line="+83"/>
         <source>MD5 hash:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-603"/>
+        <location line="-619"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1274,13 +1318,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+667"/>
+        <location line="+683"/>
         <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-626"/>
+        <location line="-639"/>
         <source>Source verification:: on</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1292,25 +1336,43 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+523"/>
+        <location line="+507"/>
         <source>(during source verification)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+40"/>
+        <location line="+69"/>
         <source>SHA256 hash:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-571"/>
+        <location line="-584"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="-36"/>
+        <source>Host name:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+1"/>
+        <source>Domain name:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>System:: %1</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+35"/>
         <source>Info  path and file name:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1328,13 +1390,26 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+535"/>
+        <location line="+516"/>
+        <source>Aborted, too many bad sectors (&gt; %1)</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Aborted because device has been inaccessible for too long (&gt; %1s)</source>
+        <oldsource>Aborted because device has is inaccessible for too long (&gt; %1s)</oldsource>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+6"/>
         <source>Aborted because of image read error during verification</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+42"/>
         <source>MD5 hash verified source:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1383,13 +1458,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-800"/>
+        <location line="-839"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+196"/>
+        <location line="+222"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1401,7 +1476,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-196"/>
+        <location line="-222"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
@@ -1419,7 +1494,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+186"/>
+        <location line="+212"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1431,12 +1506,12 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-152"/>
+        <location line="-178"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+822"/>
+        <location line="+861"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1452,47 +1527,47 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-837"/>
+        <location line="-876"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+718"/>
+        <location line="+734"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-12"/>
+        <location line="-21"/>
         <source>Aborted because acquisition failed to start</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+122"/>
+        <location line="+154"/>
         <source>No MD5 hashes available (the selected EWF format does not support image file hashes)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-659"/>
+        <location line="-672"/>
         <source>Hash calculation:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+534"/>
+        <location line="+521"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+19"/>
         <source>Aborted, strange reason (%1 %2)</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+14"/>
+        <location line="+37"/>
         <source>SHA1 hash:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1510,13 +1585,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-594"/>
+        <location line="-607"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+712"/>
+        <location line="+725"/>
         <source>Acquisition/verification aborted - file list may be incomplete</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1524,7 +1599,7 @@ Linked with libguytools %6</source>
 <context>
     <name>t_ThreadScan</name>
     <message>
-        <location filename="threadscan.cpp" line="+52"/>
+        <location filename="threadscan.cpp" line="+53"/>
         <source>Cannot scan devices</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
