@@ -11,22 +11,22 @@
 //                  deinitialisation.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #include <mcheck.h>
 #include <limits.h>
@@ -36,7 +36,11 @@
 #include <unistd.h>
 
 #include <QApplication>
-#include <QtGui>
+#if (QT_VERSION >= 0x050000)
+   #include <QtWidgets> //lint !e537 Repeated include
+#else
+   #include <QtGui>     //lint !e537 Repeated include
+#endif
 
 #include "common.h"
 
@@ -87,7 +91,7 @@ enum
 #define MAIN_LANGUAGE_FILENAME_DEFAULT "guymager_en"
 #define MAIN_LANGUAGE_FILENAME_QT      "qt_"
 #define MAIN_DEFAULT_MISCFILES_DIR     "/usr/share/guymager/"
-#define MAIN_DEFAULT_LANGUAGE_DIR_QT   "/usr/share/qt4/translations/"
+#define MAIN_DEFAULT_LANGUAGE_DIR_QT   "/usr/share/qt5/translations/"
 #ifndef SPLASH_DIR
    #define SPLASH_DIR                     MAIN_DEFAULT_MISCFILES_DIR
 #endif
@@ -118,23 +122,49 @@ static t_MainLocal MainLocal;
 //       Signal & error handling
 // ------------------------------------
 
-static void MainLogQtMessage (QtMsgType MsgType, const char *pMsg)
-{
-   const char *pMsgType;
-
-   switch (MsgType)
+#if (QT_VERSION >= 0x050000)
+   static void MainLogQtMessage (QtMsgType MsgType, const QMessageLogContext &/*Context*/, const QString &Message)
    {
-      case QtDebugMsg:   pMsgType = "Qt debug";   break;
-      case QtWarningMsg: pMsgType = "Qt warning"; break;
-      case QtFatalMsg:   pMsgType = "Qt fatal";   break;
-      default:           pMsgType = "Qt message of unknown type:"; break;
+      const char *pMsgType;
+
+      switch (MsgType)
+      {
+         case QtDebugMsg:    pMsgType = "Qt debug";    break;
+         case QtWarningMsg:  pMsgType = "Qt warning";  break;
+         case QtCriticalMsg: pMsgType = "Qt critical"; break;
+         case QtFatalMsg:    pMsgType = "Qt fatal";    break;
+         default:            pMsgType = "Qt message of unknown type:"; break;
+      }
+//      t_Log::Entry (t_Log::Info, Context.file, Context.function, Context.line, "%s: %s", pMsgType, QSTR_TO_PSZ(Message));  // Context.file/function/line contain non-interesting
+//      printf ("\n%s %s %d - %s: %s", Context.file, Context.function, Context.line, pMsgType, QSTR_TO_PSZ(Message));        // info about Qt source code
+
+      LOG_INFO ("%s: %s", pMsgType, QSTR_TO_PSZ(Message));
+      printf ("\n%s: %s\n", pMsgType, QSTR_TO_PSZ(Message));
+
+      if (MsgType == QtFatalMsg)
+         ErrorExit (EXIT_QT_FATAL);
    }
-   LOG_INFO ("%s: %s", pMsgType, pMsg)
-   printf ("\n%s: %s", pMsgType, pMsg);
+#else
+   static void MainLogQtMessage (QtMsgType MsgType, const char *pMsg)
+   {
+      const char *pMsgType;
+
+      switch (MsgType)
+      {
+         case QtDebugMsg:   pMsgType = "Qt debug";   break;
+         case QtWarningMsg: pMsgType = "Qt warning"; break;
+         case QtFatalMsg:   pMsgType = "Qt fatal";   break;
+         default:           pMsgType = "Qt message of unknown type:"; break;
+      }
+      LOG_INFO ("%s: %s", pMsgType, pMsg)
+      printf ("\n%s: %s\n", pMsgType, pMsg);
+
+      if (MsgType == QtFatalMsg)
+         ErrorExit (EXIT_QT_FATAL);
+   }
+#endif
+
 
-   if (MsgType == QtFatalMsg)
-      ErrorExit (EXIT_QT_FATAL);
-}
 
 
 // MainSignalHandler: Called by ToolSignal whenever a signal is caught
@@ -329,13 +359,26 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    // -----------------------
    QApplication::setDesktopSettingsAware (false);
    QApplication::setColorSpec (QApplication::ManyColor);
-   MainLocal.pApp = new QApplication(argc, argv);         // Create QApplication here, so the following Init functions
-   qInstallMsgHandler (MainLogQtMessage);                 // may use Qt functions, for instance for building pixmaps, fonts, ...
+   MainLocal.pApp = new QApplication(argc, argv); // Create QApplication here, so functions below may use
+                                                  // Qt functions, for instance for building pixmaps, fonts, ...
+   #if (QT_VERSION >= 0x050000)
+      qInstallMessageHandler (MainLogQtMessage);
+   #else
+      qInstallMsgHandler (MainLogQtMessage);
+   #endif
    CHK (ToolSysInfoInit ())
 
    // Check Cfg file
    // --------------
-   CHK (ToolCfgUseAdjustedCommandLine (QApplication::argc(), QApplication::argv()))
+   int      AdjustedArgc;
+   char **ppAdjustedArgv;
+
+   AdjustedArgc = QApplication::arguments().count();                  // Ask Qt for command line argument list; the list returned already has been
+   ppAdjustedArgv = (char**) malloc (AdjustedArgc * sizeof(char *));  // cleaned so that Qt specific command line parameters (such as -style=plastique)
+   for (int i=0; i<AdjustedArgc; i++)                                 // no longer figure in it.
+      ppAdjustedArgv[i] = strdup (QSTR_TO_PSZ(QApplication::arguments()[i]));
+
+   CHK (ToolCfgUseAdjustedCommandLine (AdjustedArgc, ppAdjustedArgv))
    CHK (ToolCfgSetLogFn (&MainCfgLog))
    CHK (CfgInit())
    rc = CfgGetCfgFileName (&pCfgFileName, &DefaultUsed);
