@@ -220,7 +220,7 @@ class t_OutputFileDD: public t_OutputFile
                oFileFlags &= ~O_NOATIME;
                oFile = open64 (QSTR_TO_PSZ (Filename), oFileFlags, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);
             }
-            off64_t FileSize;
+            off64_t FileSize=0;
             bool    Err = (oFile < 0);
             if (!Err) Err = ((FileSize = lseek64 (oFile,0,SEEK_END)) == -1);
             if (!Err) Err = (lseek64 (oFile, 0, SEEK_SET) != 0);
@@ -1287,7 +1287,8 @@ void t_ThreadWrite::run (void)
    {
       case t_File::EWF : if (CONFIG(EwfFormat) == t_File::AEWF)
                               pOutputFile = new t_OutputFileAEWF(this);
-                         else pOutputFile = new t_OutputFileEWF (this); break;
+                         else pOutputFile = new t_OutputFileEWF (this); 
+                         break;
       case t_File::DD  :      pOutputFile = new t_OutputFileDD  (this); break;
       case t_File::AAFF:      pOutputFile = new t_OutputFileAAFF(this); break;
       default: CHK_EXIT (ERROR_THREADWRITE_INVALID_FORMAT)
