@@ -9,22 +9,22 @@
 //  Module:         Different utility functions
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Guy Voncken
 //
-// This file is part of guymager.
+// This file is part of Guymager.
 //
-// guymager is free software: you can redistribute it and/or modify
+// Guymager is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
-// guymager is distributed in the hope that it will be useful,
+// Guymager is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with guymager. If not, see <http://www.gnu.org/licenses/>.
+// along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef __UTIL_H__
 #define __UTIL_H__
@@ -46,6 +46,8 @@ APIRET UtilGetFreeSpace (const QString &DirPath, quint64 *pFreeBytes);
 
 QString UtilSizeToHuman (unsigned long long Size, bool SI=true, int FracLen=-1, int UnitThreshold=-1);
 
+int UtilClose(FILE *pFile);
+
 class t_UtilMem
 {
    public:
